@@ -18,7 +18,7 @@ use Bio::SeqIO;
 use Bio::Gonzales::PrimarySeqIX;
 
 use 5.010;
-our $VERSION = '0.0547_01'; # VERSION
+our $VERSION = 0.01_01;
 
 has 'profile_db' => ( is => 'rw', required => 1 );
 has 'result_dir' => ( is => 'rw', required => 1 );
@@ -153,7 +153,7 @@ sub _transform_hmm_hits {
             num_marks => scalar @{ $self->domain_groups } );
         $self->_update_sequence_mark( $result_for_sequence{ $k->{seq_id} }, $k );
     }
-    $cache->close;
+    close $cache;
 
     return \%result_for_sequence;
 }
@@ -339,8 +339,8 @@ sub identify {
 
         }
     }
-    $seq_ids_fh->close;
-    $not_found->close;
+    close $seq_ids_fh;
+    close $not_found;
 }
 
 # for every group in array, grep for accession
