@@ -14,7 +14,7 @@ use Data::Dumper;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.0547_01'; # VERSION
+our $VERSION = 0.01_01;
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
@@ -105,7 +105,7 @@ sub render {
         $panel_imgs{ $result->query_name } = $img_result;
         $panel->finished;
     }
-    $fh->close unless ($fh_was_open);
+    close $fh unless ($fh_was_open);
 
     return \%panel_imgs;
 }
@@ -239,7 +239,7 @@ sub render_sep {
         $panel->finished;
     }
 
-    $fh->close unless ($fh_was_open);
+    close $fh unless ($fh_was_open);
 
     return \%panel_imgs;
 }
