@@ -7,7 +7,7 @@ use Carp;
 use Data::Dumper;
 use Bio::Gonzales::Seq::IO;
 
-our $VERSION = '0.0547_01'; # VERSION
+our $VERSION = 0.01_01;
 
 has id     => ( is => 'rw', required   => 1 );
 has desc   => ( is => 'rw', default    => '' );
@@ -147,12 +147,12 @@ sub as_primaryseq {
     -seq      => $self->seq,
     -id       => $self->id,
     -desc     => $self->desc,
-    -alphabet => $self->guess_alphabet,
+    -alphabet => $self->_guess_alphabet,
     -direct   => 1,
   );
 }
 
-sub guess_alphabet {
+sub _guess_alphabet {
   my ($self) = @_;
 
   my $str = $self->seq();
@@ -189,7 +189,7 @@ sub guess_alphabet {
 sub revcom {
   my ($self) = @_;
 
-  $self->seq( _revcom_from_string( $self->seq, $self->guess_alphabet ) );
+  $self->seq( _revcom_from_string( $self->seq, $self->_guess_alphabet ) );
 
   return $self;
 }
@@ -313,7 +313,7 @@ __END__
 
 =head1 NAME
 
-Bio::Gonzales::Seq - Gonzales Sequence Object
+Bio::Gonzales::Seq - Gonzales Seqeuence Object
 
 =head1 SYNOPSIS
 
