@@ -9,7 +9,7 @@ use YAML::XS;
 use JSON::XS;
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.0547_01'; # VERSION
+our $VERSION = 0.01;
 
 @EXPORT = qw(
     ythaw yfreeze yslurp yspew
@@ -36,7 +36,7 @@ sub _spew {
     local $/ = "\n";
 
     print $fh $data;
-    $fh->close unless $was_open;
+    close $fh unless $was_open;
 }
 
 sub _slurp {
@@ -47,7 +47,7 @@ sub _slurp {
 
     my $data = do { local $/; <$fh> };
 
-    $fh->close unless $was_open;
+    close $fh unless $was_open;
     return $data;
 }
 
@@ -60,73 +60,30 @@ __END__
 
 =head1 NAME
 
-Bio::Gonzales::Util::Cerial - convenience functions for yaml and json IO
+Bio::Gonzales::Util::Cerial - convenience functions for yaml storage
 
 =head1 SYNOPSIS
 
-    use Bio::Gonzales::Util::Cerial;
+    use Bio::Gonzales::Util::YAML;
 
-    # YAML IO
-    my $yaml_string = yfreeze(\%data);
-    my $data = ythaw($yaml_string);
-
-    yspew($filename, \%data);
-    my $data = yslurp($filename);
-
-    # JSON IO
-    my $json_string = jfreeze(\%data);
-    my $data = jthaw($json_string);
-
-    jspew($filename, \%data);
-    my $data = jslurp($filename);
+    my $yaml_string = freeze \%data;
+    my $data = thaw $yaml_string;
 
+    freeze_file $filename, \%data ;
+    my $data = thaw_file $filename;
 
 =head1 DESCRIPTION
     
-=item B<< $yaml_string = yfreeze(\%data) >>
-
-Serialize data structure as yaml string
-
-=item B<< $data = ythaw($yaml_string) >>
-
-UNserialize data structure from yaml string
-
-=item B<< yspew($filename, \%data) >>
-
-Serialize data structure as yaml string to a file
-
-=item B<< my $data = yslurp($filename) >>
-
-UNserialize data structure from yaml file
-
-=item B<< my $json_string = jfreeze(\%data) >>
-
-Serialize data structure as json string
-
-=item B<< my $data = jthaw($json_string) >>
-
-UNserialize data structure from json string
-
-=item B<< jspew($filename, \%data) >>
-
-Serialize data structure as json string to a file
-
-=item B<< my $data = jslurp($filename) >>
-
-UNserialize data structure from json file
+    Bio::Gonzales::Util::YAML provides some handy functions to work with yaml data
 
 =head1 EXPORT
 
-The following functions are exported by default
+=head2 $yaml_string = freeze($data,...);
 
-    ythaw
-    yfreeze
-    yslurp
-    yspew
+=head2 $data = thaw($yaml_string);
 
-    jthaw
-    jfreeze
-    jslurp
-    jspew
+=head2 freeze_file($filename, $data, ...);
+
+=head2 $data = thaw_file($filename);
 
 =cut
