@@ -11,7 +11,6 @@ use IO::Handle;
 use IO::Zlib;
 use IO::Uncompress::Bunzip2 qw($Bunzip2Error);
 use File::Which qw/which/;
-use Bio::Gonzales::Util::IO::Compressed;
 
 our %ZMODES = (
   '>'  => 'wb',
@@ -21,14 +20,14 @@ our %ZMODES = (
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.0547_01'; # VERSION
+our $VERSION  = 0.01_01;
 our $EXTERNAL_GZ = which('pigz') // which('gzip');
 our $EXTERNAL_BZIP2 = which('bzip2');
 
-@EXPORT      = qw(glob_regex epath bname openod spath);
+@EXPORT      = qw(rexglob epath bname openod spath);
 %EXPORT_TAGS = ();
 @EXPORT_OK
-  = qw(expand_path slurpc basename regex_glob open_on_demand is_newer splitpath %ZMODES is_archive expand_home);
+  = qw(regex_glob expand_path slurpc basename open_on_demand is_newer splitpath %ZMODES is_archive expand_home);
 
 sub epath { expand_path(@_) }
 
@@ -53,9 +52,9 @@ sub expand_home {
   return $file;
 }
 
-sub regex_glob { return glob_regex(@_) }
+sub regex_glob { return reglob(@_) }
 
-sub glob_regex {
+sub rexglob {
   my ( $dir, $re ) = @_;
 
   $dir = expand_path($dir);
@@ -73,7 +72,7 @@ sub slurpc {
 
   my ( $fh, $was_open ) = open_on_demand( $_[0], '<' );
   my @lines = map { s/\r\n/\n/; chomp; $_ } <$fh>;
-  $fh->close if ( !$was_open );
+  close $fh if ( !$was_open );
 
   return wantarray ? @lines : \@lines;
 }
@@ -137,7 +136,7 @@ sub open_on_demand {
   if (wantarray) {
     return ( $fh, $fh_was_open );
   } elsif ($fh_was_open) {
-    carp "it is not advisable to use open_on_demand\n in scalar context with previously opened filehandle";
+    confess "it is not possible to use open_on_demand\n in scalar context with previously opened filehandle";
   }
   return $fh;
 }
@@ -150,19 +149,19 @@ sub _pipe_z {
     return $fh;
   } elsif ( $mode eq '>' ) {
     my ( $r, $w );
-    pipe( $r, $w ) || die "gz pipe failed: $!";
+    pipe( $r, $w ) || die "pigz pipe failed: $!";
     my $pid = fork();
-    $SIG{PIPE} = sub { die "whoops, gz pipe broke" };
-    defined($pid) || die "gz fork failed: $!";
+    $SIG{PIPE} = sub { die "whoops, pigz pipe broke" };
+    defined($pid) || die "pigz fork failed: $!";
     if ($pid) {
-      $r->close;
-      #return $w;
-      return Bio::Gonzales::Util::IO::Compressed->new($w, $pid);
+      close $r;
+      return $w;
     } else {
-      open( STDIN, "<&", $r ) || die "can't reopen gz STDIN: $!";
-      $w->close || die "can't close gz WRITER: $!";
+      open( STDIN, "<&", $r ) || die "can't reopen pigz STDIN: $!";
+      close($w) || die "can't close pigz WRITER: $!";
       open STDOUT, '>', $f or die "Can't open filehandle: $!";
       exec( $gz, '-c' );
+      exit(0);
     }
   }
 
@@ -210,7 +209,7 @@ Bio::Gonzales::Util::File - Utility functions for file stuff
 
 =head1 SYNOPSIS
 
-    use Bio::Gonzales::Util::File qw(glob_regex expand_path slurpc basename open_on_demand is_newer);
+    use Bio::Gonzales::Util::File qw(regex_glob expand_path slurpc basename open_on_demand is_newer);
 
 =head1 DESCRIPTION
 
@@ -254,7 +253,7 @@ C<$basename>, C<$suffix> ) in list context. Filename example:
 
 Expands F<~> in all supplied files and returns the crap.
 
-=item B<< @files = glob_regex($dir, $file_regex) >>
+=item B<< @files = regex_glob($dir, $file_regex) >>
 
 Selects files from C<$dir> based on the supplied C<$file_regex>.
 
